summaryrefslogtreecommitdiff
path: root/include/X11/extensions/XInput2.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/X11/extensions/XInput2.h')
-rw-r--r--include/X11/extensions/XInput2.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/X11/extensions/XInput2.h b/include/X11/extensions/XInput2.h
index 60138b1..4ef622c 100644
--- a/include/X11/extensions/XInput2.h
+++ b/include/X11/extensions/XInput2.h
@@ -157,12 +157,12 @@ typedef struct {
int extension; /* XI extension offset */
int evtype; /* XI_DeviceHierarchyChangedNotify */
Time time;
- XID deviceid; /* id of the device that changed */
- XID slaveid; /* id of the slave device that caused the
- change */
+ int deviceid; /* id of the device that changed */
+ int sourceid; /* Source for the new classes. */
+ int reason; /* Reason for the change */
int num_classes;
- XIAnyClassInfo *inputclassinfo; /* same as in XDeviceInfo */
-} XDeviceClassesChangedEvent;
+ XIAnyClassInfo **classes; /* same as in XIDeviceInfo */
+} XIDeviceChangedEvent;
typedef struct
{